@@ -106,6 +106,10 @@ pub struct LintConfig {
     #[serde(default)]
     pub eqeqeq: RuleConfig<EqeqeqConfig>,
 
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default, alias = "noLoopFunc")]
+    pub no_loop_func: RuleConfig<()>,
+
     #[cfg(feature = "non_critical_lints")]
     #[serde(default, alias = "noNew")]
     pub no_new: RuleConfig<()>,
